<?php
/*!
  \file
  \brief ץɽ

  \author Satofumi KAMIMURA

  $Id$
*/

require_once("includes/smartySettings.php");
$o_smarty = new SmartySettings();

require_once("includes/langUpload.php");
$user = new UserAuthorize();

if ($user->requireReload() || ! $user->isLogin()) {
  header('Location: index.php');
  return;
}

$lang = new LangUpload();
$lang->handleCommentRequest($user);
$lang->updateReadTime();

if ($lang->sendComment()) {
  header('Location: programView.php#comment');
  return;
}
if ($lang->programUpdated()) {
  header('Location: programView.php');
  return;
}

$o_smarty->assign('user', $user);
$o_smarty->assign('lang', $lang);
$o_smarty->display('programView.tpl');
?>
